==> haskell-cryptohash-cryptoapi-0.1.4-29-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cryptohash-cryptoapi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptohash-cryptoapi
version: 0.1.4
id: cryptohash-cryptoapi-0.1.4-9ZuVpclRcqtWHJwVug3zA
key: cryptohash-cryptoapi-0.1.4-9ZuVpclRcqtWHJwVug3zA
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
homepage: https://github.com/vincenthz/hs-cryptohash-cryptoapi
synopsis: Crypto-api interfaces for cryptohash
description:
    Crypto-api interfaces for cryptohash
category: Cryptography
abi: 08aa888e4b6d11dd84070777f7f77ab2
exposed: True
exposed-modules:
    Crypto.Hash.CryptoAPI
import-dirs: /usr/lib/ghc-8.4.3/site-local/cryptohash-cryptoapi-0.1.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/cryptohash-cryptoapi-0.1.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/cryptohash-cryptoapi-0.1.4
hs-libraries: HScryptohash-cryptoapi-0.1.4-9ZuVpclRcqtWHJwVug3zA
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    cereal-0.5.7.0-GeNBgd8Wa452X4EoKnwsnC
    crypto-api-0.13.3-H6IfzwtYtsODXXfSTi5z5x
    cryptonite-0.25-FGChimResic4ujDRfnuPjv
    memory-0.14.18-9akydHRk1ZP1zabNg9e0SJ
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             cereal-0.5.7.0-GeNBgd8Wa452X4EoKnwsnC=91a5befe140ca1e57734aef5b9be7102
             crypto-api-0.13.3-H6IfzwtYtsODXXfSTi5z5x=77fff9de6de15e8cfa3572530a17c761
             cryptonite-0.25-FGChimResic4ujDRfnuPjv=29137cb7d1f614608fd8f81085dbaf61
             memory-0.14.18-9akydHRk1ZP1zabNg9e0SJ=a6560a06cd4458200b1075ace7506fc2
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=4bf567357cce5e796341c1faefad6985
haddock-interfaces: /usr/share/doc/haskell-cryptohash-cryptoapi/html/cryptohash-cryptoapi.haddock
haddock-html: /usr/share/doc/haskell-cryptohash-cryptoapi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cryptohash-cryptoapi-0.1.4-32-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cryptohash-cryptoapi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptohash-cryptoapi
version: 0.1.4
id: cryptohash-cryptoapi-0.1.4-4mIcqIV7erZLuH01FzYt2r
key: cryptohash-cryptoapi-0.1.4-4mIcqIV7erZLuH01FzYt2r
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
homepage: https://github.com/vincenthz/hs-cryptohash-cryptoapi
synopsis: Crypto-api interfaces for cryptohash
description:
    Crypto-api interfaces for cryptohash
category: Cryptography
abi: 1fb1b621412b01d59a7058faeb53a333
exposed: True
exposed-modules:
    Crypto.Hash.CryptoAPI
import-dirs: /usr/lib/ghc-8.6.1/site-local/cryptohash-cryptoapi-0.1.4
library-dirs: /usr/lib/ghc-8.6.1/site-local/cryptohash-cryptoapi-0.1.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/cryptohash-cryptoapi-0.1.4
hs-libraries: HScryptohash-cryptoapi-0.1.4-4mIcqIV7erZLuH01FzYt2r
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    cereal-0.5.7.0-2uER3Agem8P6aYfM1x47n8
    crypto-api-0.13.3-43rwgg6didD9Ww3YkDbwy5
    cryptonite-0.25-5E9EuEAz1M1JrY25iIyNbL
    memory-0.14.18-7DMShoecVUC5dB7z3aQ1xS
    tagged-0.8.6-FABECvKnqYbBCttH1EeJvB
haddock-interfaces: /usr/share/doc/haskell-cryptohash-cryptoapi/html/cryptohash-cryptoapi.haddock
haddock-html: /usr/share/doc/haskell-cryptohash-cryptoapi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
